@@ -177,9 +177,9 @@ class WebDriver(object):
         if not isinstance(capabilities, dict):
             raise InvalidArgumentException("Capabilities must be a dictionary")
         w3c_caps = {"firstMatch": [], "alwaysMatch": {}}
-        w3c_caps.update(capabilities)
         if browser_profile:
-            w3c_caps["firstMatch"].append({"firefox_profile": browser_profile.encoded})
+            capabilities["moz:firefoxOptions"]["profile"] = browser_profile.encoded
+        w3c_caps["alwaysMatch"].update(capabilities)
         parameters = {"capabilities": w3c_caps,
                       "desiredCapabilities": capabilities}
         response = self.execute(Command.NEW_SESSION, parameters)
@@ -837,7 +837,18 @@ class WebDriver(object):
             del png
         return True
 
-    save_screenshot = get_screenshot_as_file
+    def save_screenshot(self, filename):
+        """
+        Gets the screenshot of the current window. Returns False if there is
+           any IOError, else returns True. Use full paths in your filename.
+
+        :Args:
+         - filename: The full path you wish to save your screenshot to.
+
+        :Usage:
+            driver.save_screenshot('/Screenshots/foo.png')
+        """
+        return self.get_screenshot_as_file(filename)
 
     def get_screenshot_as_png(self):
         """
@@ -957,6 +968,7 @@ class WebDriver(object):
         return self.execute(Command.SET_WINDOW_RECT, {"x": x, "y": y,
                                                       "width": width,
                                                       "height": height})['value']
+
     @property
     def file_detector(self):
         return self._file_detector
